#include <gui/window.h>
#include <gui/requesters.h>
#include <util/application.h>

#include "fontwin.h"

using namespace os;

class MyApp : public Application
{
    public:
    MyApp() : Application("application/x-vnd.Demo-Font") {
    	m_pcWindow = new FontWin( Rect( 100, 100, 500, 250 ) );
    	m_pcWindow->Show();
    }

    ~MyApp() {
    }

    private:
    Window *m_pcWindow;
};

int main(void)
{
    MyApp *pcApp = new MyApp();

    pcApp->Run();
}
