#ifndef __FONTWIN_H__
#define __FONTWIN_H__

#include <gui/window.h>
#include <util/message.h>

class FontWin : public os::Window
{
public:
    FontWin( const os::Rect& cRect );
    ~FontWin();
	
    virtual bool OkToQuit();
private:

};

#endif // __FONTWIN_H__
